//Tripod modification Z axis of Tronxy X5 3D printer
//For details see:
//http://homofaciens.de/technics-machines-3D-printer-Tronxy-X5_en.htm

drill_hole = 3.5;
wall_thickness = 5;

width = 35;
length = 130;
thickness = 5;

socket_width = 20;
socket_height = 20;
socket_cut = 2;
socket_hole = 8;
socket_drill_hole = 4.4;
socket_inwards = 10;

//Nut holder
holder_width = 40;
holder_length = 60;
holder_thickness = 10;
nut_diameter = 15;
nut_thickness = 6.5;
bar_thickness = 4;
bar_width = 20;
rod_diameter = 10;


//Uncomment lines to draw objects

/*
translate([0, 0, 0]){
  BearingHolder();
}

translate([0, 60, 0]){
  BearingHolderClamp();
}

translate([50, 0, 0]){
  rotate([0, 0, 90]){
    linear_bearing();
  }
}
*/

//SquareTubeSocket();


//RoundBarSocket(1, 8);

//Rear socked for threaded rod
translate([35, 40, 0]){
  RoundBarSocket(0, 8.5);
}


//RoundBarSocketAsymetric();

translate([35, 40, 0]){
  mirror([0, 1, 0]){
    //RoundBarSocketAsymetric();
  }
}


//StepperMotor();

//AngleJointStepperMotor();

//MotorCoupler(0, 0);

//NutHolder();

translate([0, 45, 0]){
  //NutHolderClamp();
}

//RearNutHolder();

//SpindleSocket();
 
//AngleJoint();

//CableClamp();

//YMotorMount();
//SpoolHolder();

module YMotorMount(){
  motor_width = 43;
  hole_distance = 30;
  thickness = 4;
  hole_diameter = 3.5;
  mount_hole_diameter = 4.5;
  mount_length = motor_width + 20;
  mount_width = 20;
  
  difference(){
    cube(size = [motor_width, motor_width, thickness], center = true);
    translate([hole_distance / 2, hole_distance / 2, 0]){
      cylinder($fn = 200, h = thickness * 1.1, r = hole_diameter / 2, center = true);
    }
    translate([-hole_distance / 2, hole_distance / 2, 0]){
      cylinder($fn = 200, h = thickness * 1.1, r = hole_diameter / 2, center = true);
    }
    translate([-hole_distance / 2, -hole_distance / 2, 0]){
      cylinder($fn = 200, h = thickness * 1.1, r = hole_diameter / 2, center = true);
    }
    translate([hole_distance / 2, -hole_distance / 2, 0]){
      cylinder($fn = 200, h = thickness * 1.1, r = hole_diameter / 2, center = true);
    }
  }
  translate([hole_distance/2, 0, 0]){
    difference(){
      cube(size = [mount_width, mount_length, thickness], center = true);
      translate([-hole_distance/2, 0, 0]){
        cube(size = [motor_width, motor_width, thickness * 1.1], center = true);
      }
      translate([0, mount_length / 2, 0]){
        cylinder($fn = 200, h = thickness * 1.1, r = mount_hole_diameter / 2, center = true);
      }
      translate([0, -mount_length / 2, 0]){
        cylinder($fn = 200, h = thickness * 1.1, r = mount_hole_diameter / 2, center = true);
      }
    }
  }
  translate([hole_distance/2, mount_length / 2, 0]){
    difference(){
      cylinder($fn = 200, h = thickness, r = mount_width / 2, center = true);
      cylinder($fn = 200, h = thickness * 1.1, r = mount_hole_diameter / 2, center = true);
    }
  }
  translate([hole_distance/2, -mount_length / 2, 0]){
    difference(){
      cylinder($fn = 200, h = thickness, r = mount_width / 2, center = true);
      cylinder($fn = 200, h = thickness * 1.1, r = mount_hole_diameter / 2, center = true);
    }
  }
  
}

module CableClamp(){
  clamp_thickness = 2;
  clamp_height = 5;
  clamp_edge = 7;
  clamp_distance = 1;
  hook_length = 2;
  hook_depth = 3;

  inner_radius = 3.5;
  outer_radius = inner_radius + clamp_thickness;
  
  linear_extrude(height = clamp_height){
    difference(){
      polygon(points = [ [0, 0], 
                          [-hook_length, 0],
                          [clamp_thickness, -hook_depth],
                          [clamp_thickness,clamp_edge - clamp_thickness],
                          [clamp_edge - clamp_thickness,clamp_edge - clamp_thickness],
                          [clamp_edge - clamp_thickness,-hook_depth],
                          [clamp_edge + hook_length,0],
                          [clamp_edge,0],
                          [clamp_edge,clamp_edge],
                          [0,clamp_edge],
                          [0,0]
      

                        ], convexity = 10, slices = 20);
      translate([clamp_edge/2, outer_radius + clamp_distance, 0]){
        circle(r = inner_radius, $fn = 200);
      }
    }
    translate([clamp_edge/2, outer_radius + clamp_distance, 0]){
      difference(){
        circle(r = outer_radius, $fn = 200);
        circle(r = inner_radius, $fn = 200);
        translate([0, -outer_radius/2, 0]){
          square(size=[clamp_edge, outer_radius], center = true);
        }
      }
    }
    
  }
  
}

module AngleJointStepperMotor(){
  edge = 10;
  hole_distance1 = 81;
  hole_distance2 = 30;
  hole_pos = 10;
  width = hole_distance1 + 2 * edge;
  wall_thickness = 3;
  length1 = 43;
  length2 = 20;
  enforcement = 7;
  wall_thickness = 3;
  

  rotate([0, 0, 0]){
    translate([width/4, length1/2 - wall_thickness/2, wall_thickness]){
      linear_extrude(height = length2 - wall_thickness, scale=[1, 0]){
        translate([0, -length1/2 + wall_thickness/4, 0]){
          square(size = [wall_thickness, length1 - wall_thickness/2], center = true);
        }
      }
    }
    translate([width*3/4, length1/2 - wall_thickness/2, wall_thickness]){
      linear_extrude(height = length2 - wall_thickness, scale=[1, 0]){
        translate([0, -length1/2 + wall_thickness/4, 0]){
          square(size = [wall_thickness, length1 - wall_thickness/2], center = true);
        }
      }
    }
    translate([wall_thickness/2, length1/2 - wall_thickness/2, wall_thickness]){
      linear_extrude(height = length2 - wall_thickness, scale=[1, 0]){
        translate([0, -length1/2 + wall_thickness/4, 0]){
          square(size = [wall_thickness, length1 - wall_thickness/2], center = true);
        }
      }
    }
    translate([width - wall_thickness/2, length1/2 - wall_thickness/2, wall_thickness]){
      linear_extrude(height = length2 - wall_thickness, scale=[1, 0]){
        translate([0, -length1/2 + wall_thickness/4, 0]){
          square(size = [wall_thickness, length1 - wall_thickness/2], center = true);
        }
      }
    }
    translate([width/2, 0, wall_thickness / 2]){
      difference(){
        cube(size = [width, length1, wall_thickness], center = true);
        translate([hole_distance1/2, length1/2 - hole_pos, 0]){
          cylinder($fn = 200, h = wall_thickness * 1.1, r = socket_drill_hole / 2, center = true);
        }
        translate([-hole_distance1/2, length1/2 - hole_pos, 0]){
          cylinder($fn = 200, h = wall_thickness * 1.1, r = socket_drill_hole / 2, center = true);
        }
      }
    }
    rotate([-90, 0, 0]){
      translate([width/2, -length2/2, length1/2]){
        difference(){
          cube(size = [width, length2, wall_thickness], center = true);
          translate([-hole_distance2/2, 0, 0]){
            cylinder($fn = 200, h = wall_thickness * 1.1, r = socket_drill_hole / 2, center = true);
          }
          translate([hole_distance2/2, 0, 0]){
            cylinder($fn = 200, h = wall_thickness * 1.1, r = socket_drill_hole / 2, center = true);
          }
        }
      }
    }
  }
  
}


module AngleJoint(){
  width = 20;
  wall_thickness = 3;
  length = 10 + wall_thickness;
  enforcement = 7;
  

  rotate([0, -90, 0]){
    translate([width/2, length/2, 0]){
      linear_extrude(height = enforcement, scale=[1, 0]){
        translate([0, -enforcement/2, 0]){
          square(size = [width, enforcement], center = true);
        }
      }
    }
    translate([width/2, 0, wall_thickness / 2]){
      difference(){
        cube(size = [width, length, wall_thickness], center = true);
        translate([0, -length/2, 0]){
          cylinder($fn = 200, h = wall_thickness * 1.1, r = socket_drill_hole / 2, center = true);
        }
      }
      translate([0, -length/2, 0]){
        difference(){
          cylinder($fn = 200, h = wall_thickness, r = width / 2, center = true);
          cylinder($fn = 200, h = wall_thickness * 1.1, r = socket_drill_hole / 2, center = true);
        }
      }
    }
    rotate([-90, 0, 0]){
      translate([width/2, -length/2, length/2]){
        difference(){
          cube(size = [width, length, wall_thickness], center = true);
          translate([0, -length/2, 0]){
            cylinder($fn = 200, h = wall_thickness * 1.1, r = socket_drill_hole / 2, center = true);
          }
        }
        translate([0, -length/2, 0]){
          difference(){
            cylinder($fn = 200, h = wall_thickness, r = width / 2, center = true);
            cylinder($fn = 200, h = wall_thickness * 1.1, r = socket_drill_hole / 2, center = true);
          }
        }
      }
    }
  }
  
}

module SpindleSocket(){
  socket_width = 15;
  rod_diameter = 8.5;
  socket_inwards = 43/2;
  edge = 3;
  length = socket_inwards + rod_diameter/2 + edge;
  
  translate([0, 0, socket_width / 2]){
    translate([length/2, 0, 0]){
      difference(){
        cube(size = [length, rod_diameter + 2 * edge, socket_width], center = true);
        translate([-length/2 + socket_inwards, 0, 0]){
          cylinder($fn = 200, h = socket_height * 1.1, r = rod_diameter / 2, center = true);
        }
      }
    }
    rotate([0, 90, 0]){
      translate([0, 0, (wall_thickness) / 2]){
        difference(){
          cube(size = [socket_width, socket_width * 2, wall_thickness], center = true);
          translate([0, 0, socket_inwards - wall_thickness/2]){
            rotate([0, -90, 0]){
              cylinder($fn = 200, h = socket_width * 1.1, r = rod_diameter / 2, center = true);
            }
          }
          translate([0, socket_width, 0]){
            cylinder($fn = 200, h = wall_thickness * 1.1, r = socket_drill_hole / 2, center = true);
          }
          translate([0, -socket_width, 0]){
            cylinder($fn = 200, h = wall_thickness * 1.1, r = socket_drill_hole / 2, center = true);
          }
        }
        translate([0, -socket_width, 0]){
          difference(){
            cylinder($fn = 200, h = wall_thickness, r = socket_width / 2, center = true);
            cylinder($fn = 200, h = wall_thickness * 1.1, r = socket_drill_hole / 2, center = true);
          }
        }
        translate([0,   socket_width, 0]){
          difference(){
            cylinder($fn = 200, h = wall_thickness, r = socket_width / 2, center = true);
            cylinder($fn = 200, h = wall_thickness * 1.1, r = socket_drill_hole / 2, center = true);
          }
        }
      }
    }
  }
}

module RearNutHolder(){
  holder_length = 30;
  holder_width = 20;
  holder_thickness = 10;
  drill_distance = 16.5;
  
  translate([0, 0, holder_thickness/2]){
    difference(){
      cube(size = [holder_width, holder_length, holder_thickness], center = true);
      translate([0, 0, (holder_thickness - nut_thickness)/2]){
        cylinder($fn = 6, h = nut_thickness * 1.01, r = nut_diameter / 2, center = true);
        cylinder($fn = 200, h = holder_thickness * 10, r = rod_diameter / 2, center = true);
      }
      translate([0, drill_distance/2, 0]){
        cylinder($fn = 200, h = holder_thickness * 10, r = drill_hole / 2, center = true);
      }
      translate([0, -drill_distance/2, 0]){
        cylinder($fn = 200, h = holder_thickness * 10, r = drill_hole / 2, center = true);
      }
    }
  }
}

module NutHolder(){
  translate([0, 0, holder_thickness/2]){
    difference(){
      cube(size = [holder_length, holder_width, holder_thickness], center = true);
      translate([(holder_length-nut_diameter)/2 - 5, 0, (holder_thickness - nut_thickness)/2]){
        cylinder($fn = 6, h = nut_thickness * 1.1, r = nut_diameter / 2, center = true);
        cylinder($fn = 200, h = holder_thickness * 10, r = rod_diameter / 2, center = true);
      }
      translate([-nut_diameter - 10, 0, holder_thickness/2]){      
        cube(size = [holder_length, bar_width, bar_thickness], center = true);
      }
      translate([-(holder_length)/2 + 5, holder_width/2 - (holder_width - bar_width)/4, 0]){
        cylinder($fn = 200, h = holder_thickness * 1.1, r = drill_hole / 2, center = true);
      }
      translate([(holder_length)/2 - 15 - nut_diameter, holder_width/2 - (holder_width - bar_width)/4, 0]){
        cylinder($fn = 200, h = holder_thickness * 1.1, r = drill_hole / 2, center = true);
      }
      translate([-(holder_length)/2 + 5, -holder_width/2 + (holder_width - bar_width)/4, 0]){
        cylinder($fn = 200, h = holder_thickness * 1.1, r = drill_hole / 2, center = true);
      }
      translate([(holder_length)/2 - 15 - nut_diameter, -holder_width/2 + (holder_width - bar_width)/4, 0]){
        cylinder($fn = 200, h = holder_thickness * 1.1, r = drill_hole / 2, center = true);
      }
    }
  }
}

module NutHolderClamp(){
  clamp_thickness = 10;
  clamp_length = holder_length - nut_diameter - 10;
  translate([0, 0, holder_thickness/2]){
    difference(){
      cube(size = [clamp_length, holder_width, clamp_thickness], center = true);
      translate([0, 0, clamp_thickness/2 + 1]){
        cube(size = [clamp_length * 1.1, bar_width, bar_thickness], center = true);
      }
      translate([-(clamp_length)/2 + 5, holder_width/2 - (holder_width - bar_width)/4, 0]){
        cylinder($fn = 200, h = holder_thickness * 1.1, r = drill_hole / 2, center = true);
      }
      translate([(clamp_length)/2 - 5, holder_width/2 - (holder_width - bar_width)/4, 0]){
        cylinder($fn = 200, h = holder_thickness * 1.1, r = drill_hole / 2, center = true);
      }
      translate([(clamp_length)/2 - 5, -holder_width/2 + (holder_width - bar_width)/4, 0]){
        cylinder($fn = 200, h = holder_thickness * 1.1, r = drill_hole / 2, center = true);
      }
      translate([-(clamp_length)/2 + 5, -holder_width/2 + (holder_width - bar_width)/4, 0]){
        cylinder($fn = 200, h = holder_thickness * 1.1, r = drill_hole / 2, center = true);
      }
    }
  }

}


module MotorCoupler(brim_height = 0.5, brim_diameter = 33){
  coupler_diameter = 18;
  coupler_height = 16;
  seperator_height = 1;
  motor_shaft = 5.2;
  motor_shaft_height = 10;
  rod_diameter = 8;
  translate([0, 0, brim_height/2]){
    difference(){
      cylinder($fn = 200, h = brim_height, r = brim_diameter / 2, center = true);
       cylinder($fn = 200, h = coupler_height, r = coupler_diameter / 2, center = true);
    }
  }
  
  translate([0, 0, coupler_height/2]){
    difference(){
       cylinder($fn = 200, h = coupler_height, r = coupler_diameter / 2, center = true);
      translate([0, 0, (-coupler_height + motor_shaft_height)/2]){
        cylinder($fn = 200, h = motor_shaft_height + 0.04, r = motor_shaft / 2, center = true);
      }
      translate([0, 0, motor_shaft_height-motor_shaft_height/2]){
        cylinder($fn = 6, h = coupler_height - motor_shaft_height + 0.04, r = nut_diameter / 2, center = true);
      }
    }
    translate([0, 0, motor_shaft_height-(coupler_height - seperator_height)/2]){
      cylinder($fn = 200, h = seperator_height, r = coupler_diameter / 2, center = true);
    }
    
      translate([0, motor_shaft*0.83, (-coupler_height + motor_shaft_height)/2]){
        cube(size = [motor_shaft, motor_shaft, motor_shaft_height], center = true);
      }
  }
}

//Mount stepper motor
module StepperMotor(){
  motor_width = 43;
  motor_height = 41;
  base_height = 3;
  base_length = 81;
  base_width = 20;
  motor_wall = 10;
  motor_shaft_cut = 25;
  motor_drill_holes = 31;
  motor_cut = 23;
  
  rotate([-90, 0, 0]){
    translate([0, -base_width / 2, 0]){
      translate([0, -(motor_width - base_width)/2, 0]){
        cube(size = [motor_width + motor_wall * 2, motor_width, base_height], center = true);
      }
      difference(){
        cube(size = [base_length, base_width, base_height], center = true);
        translate([base_length/2, 0, 0]){
          cylinder($fn = 200, h = base_height * 1.1, r = socket_drill_hole / 2, center = true);
        }
        translate([-base_length/2, 0, 0]){
          cylinder($fn = 200, h = base_height * 1.1, r = socket_drill_hole / 2, center = true);
        }
      }
      translate([base_length/2, 0, 0]){
        difference(){
          cylinder($fn = 200, h = base_height, r = base_width / 2, center = true);
          cylinder($fn = 200, h = base_height * 1.1, r = socket_drill_hole / 2, center = true);
        }
      }
      translate([-base_length/2, 0, 0]){
        difference(){
          cylinder($fn = 200, h = base_height, r = base_width / 2, center = true);
          cylinder($fn = 200, h = base_height * 1.1, r = socket_drill_hole / 2, center = true);
        }
      }
      translate([(motor_width + motor_wall)/2, -(motor_width - base_width)/2, (base_height + motor_height)/2]){
        cube(size = [motor_wall, motor_width, motor_height], center = true);
      }
      translate([-(motor_width + motor_wall)/2, -(motor_width - base_width)/2, (base_height + motor_height)/2]){
        cube(size = [motor_wall, motor_width, motor_height], center = true);
      }
      translate([0, -(motor_width - base_width)/2, motor_height + (base_height + motor_wall)/2]){
        difference(){
          cube(size = [motor_width + motor_wall * 2, motor_width, motor_wall], center = true);
          translate([0, - motor_width/2, 0]){
            cube(size = [motor_cut, motor_width, motor_wall * 1.1], center = true);
          }
          cylinder($fn = 200, h = motor_wall * 1.1, r = motor_shaft_cut / 2, center = true);
          translate([motor_drill_holes/2, motor_drill_holes/2, 0]){
            cylinder($fn = 200, h = motor_wall * 1.1, r = drill_hole / 2, center = true);
          }
          translate([-motor_drill_holes/2, -motor_drill_holes/2, 0]){
            cylinder($fn = 200, h = motor_wall * 1.1, r = drill_hole / 2, center = true);
          }
          translate([-motor_drill_holes/2, motor_drill_holes/2, 0]){
            cylinder($fn = 200, h = motor_wall * 1.1, r = drill_hole / 2, center = true);
          }
          translate([motor_drill_holes/2, -motor_drill_holes/2, 0]){
            cylinder($fn = 200, h = motor_wall * 1.1, r = drill_hole / 2, center = true);
          }
        }
      }
    }
  }
}

//socket for round bar
module RoundBarSocket(cut = 1, socket_hole_d = 8){
  translate([0, 0, socket_height / 2]){
    translate([socket_inwards/2, 0, 0]){
      difference(){
        cube(size = [socket_width + socket_inwards, socket_width, socket_height], center = true);
        translate([socket_inwards/2, 0, 0]){
          cylinder($fn = 200, h = socket_height * 1.1, d = socket_hole_d, center = true);
          translate([socket_width / 2, 0, 0]){
            if(cut==1){
              cube(size = [socket_width, socket_cut, socket_height * 1.1], center = true);
            }
          }
        }
      }
    }
    translate([0, 0, -(socket_height - wall_thickness) / 2]){
      difference(){
        cube(size = [socket_width, socket_width * 2, wall_thickness], center = true);
        translate([socket_inwards, 0, 0]){
          cylinder($fn = 200, h = socket_height * 1.1, d = socket_hole_d, center = true);
        }
        if(cut==1){
          translate([socket_width / 2, 0, 0]){
            cube(size = [socket_width, socket_cut, socket_height * 1.1], center = true);
          }
        }
        translate([0, socket_width, 0]){
          cylinder($fn = 200, h = wall_thickness * 1.1, r = socket_drill_hole / 2, center = true);
        }
        translate([0, -socket_width, 0]){
          cylinder($fn = 200, h = wall_thickness * 1.1, r = socket_drill_hole / 2, center = true);
        }
      }
      translate([0, -socket_width, 0]){
        difference(){
          cylinder($fn = 200, h = wall_thickness, r = socket_width / 2, center = true);
          cylinder($fn = 200, h = wall_thickness * 1.1, r = socket_drill_hole / 2, center = true);
        }
      }
      translate([0,   socket_width, 0]){
        difference(){
          cylinder($fn = 200, h = wall_thickness, r = socket_width / 2, center = true);
          cylinder($fn = 200, h = wall_thickness * 1.1, r = socket_drill_hole / 2, center = true);
        }
      }
    }
  }
}

//socket for round bar
module RoundBarSocketAsymetric(){
  
  translate([0, 0, socket_height / 2]){
    translate([socket_inwards/2, 0, 0]){
      difference(){
        cube(size = [socket_width + socket_inwards, socket_width, socket_height], center = true);
        translate([socket_inwards/2, 0, 0]){
          cylinder($fn = 200, h = socket_height * 1.1, r = socket_hole / 2, center = true);
          translate([socket_width / 2, 0, 0]){
            cube(size = [socket_width, socket_cut, socket_height * 1.1], center = true);
          }
        }
      }
    }
    translate([0, 0, -(socket_height - wall_thickness) / 2]){
      difference(){
        translate([0, socket_width, 0]){
          cube(size = [socket_width, socket_width * 2, wall_thickness], center = true);
        }
        translate([socket_inwards, 0, 0]){
          cylinder($fn = 200, h = socket_height * 1.1, r = socket_hole / 2, center = true);
        }
        translate([socket_width / 2, 0, 0]){
          cube(size = [socket_width, socket_cut, socket_height * 1.1], center = true);
        }
        translate([0, socket_width, 0]){
          cylinder($fn = 200, h = wall_thickness * 1.1, r = socket_drill_hole / 2, center = true);
        }
        translate([0, socket_width * 2, 0]){
          cylinder($fn = 200, h = wall_thickness * 1.1, r = socket_drill_hole / 2, center = true);
        }
      }
      translate([0, socket_width * 2, 0]){
        difference(){
          cylinder($fn = 200, h = wall_thickness, r = socket_width / 2, center = true);
          cylinder($fn = 200, h = wall_thickness * 1.1, r = socket_drill_hole / 2, center = true);
        }
      }
    }
  }
}

//socket for square tube
module SquareTubeSocket(){
  bar_width = 20.2;
  edge = 5;
  socket_width = 20;
  socket_cut = 2;
  socket_hole = 8;
  socket_drill_hole = 4.4;
  socket_inwards = 5;
  socket_height = bar_width * sqrt(2) + socket_inwards + edge;
  socket_length = bar_width * sqrt(2) + edge * 2 + socket_width;

  
  rotate([0, -90, 0]){
    translate([socket_width/2, 0, socket_height / 2]){
        difference(){
          cube(size = [socket_width, bar_width * sqrt(2) + 2 * edge, socket_height], center = true);
          translate([0, 0, socket_inwards - (socket_height - bar_width * sqrt(2))/2]){
            rotate([90, 45, 90]){
              cube(size = [bar_width, bar_width, socket_width * 1.1], center = true);
            }
          }
        }
      translate([0, 0, -(socket_height - wall_thickness) / 2]){
        difference(){
          cube(size = [socket_width, socket_length, wall_thickness], center = true);
          translate([0, socket_length/2, 0]){
            cylinder($fn = 200, h = wall_thickness * 1.1, r = socket_drill_hole / 2, center = true);
          }
          translate([0, -socket_length/2, 0]){
            cylinder($fn = 200, h = wall_thickness * 1.1, r = socket_drill_hole / 2, center = true);
          }
        }
        translate([0, -socket_length/2, 0]){
          difference(){
            cylinder($fn = 200, h = wall_thickness, r = socket_width / 2, center = true);
            cylinder($fn = 200, h = wall_thickness * 1.1, r = socket_drill_hole / 2, center = true);
          }
        }
        translate([0,   socket_length/2, 0]){
          difference(){
            cylinder($fn = 200, h = wall_thickness, r = socket_width / 2, center = true);
            cylinder($fn = 200, h = wall_thickness * 1.1, r = socket_drill_hole / 2, center = true);
          }
        }
      }
    }
  }
}

//bar with bearing
module BearingHolder(){
  thickness = 10;
  length = 20;
  width = 40;
  edge = 5;
  mount_thickness = 10;
  mount_width = 52.8;
  mount_length = 3;
  wall_thickness = 3;
  

  translate([length/2, 0, 0]){
    rotate([90, 0, 90]){
      linear_bearing();
    }
  }

/*
  translate([10, 0, thickness]){
    cube(size = [50, 1, 1], center = true);    
  }
*/
/*
  translate([length/2, (wall_thickness + width)/2, thickness]){
    linear_extrude(height = 30, scale=[0, 1]){
      translate([-length/2, 0, 0]){
        square(size = [length, wall_thickness], center = true);
      }
    }
  }
*/
/*
  translate([(length + mount_length)/2, 0, thickness / 2]){
    difference(){
      cube(size = [mount_length, mount_width, mount_thickness], center = true);    
      translate([0, mount_width/2, 0]){
        rotate([0, 90, 0]){
           cylinder($fn = 200, h = mount_thickness * 1.1, r = drill_hole / 2, center = true);
        }
      }
      translate([0, -mount_width/2, 0]){
        rotate([0, 90, 0]){
           cylinder($fn = 200, h = mount_thickness * 1.1, r = drill_hole / 2, center = true);
        }
      }
    }
      translate([0, mount_width/2, 0]){
        rotate([0, 90, 0]){
          difference(){
           cylinder($fn = 200, h = mount_length, r = mount_thickness / 2, center = true);
            cylinder($fn = 200, h = mount_thickness * 1.1, r = drill_hole / 2, center = true);
          }
        }
      }
      translate([0, -mount_width/2, 0]){
        rotate([0, 90, 0]){
          difference(){
           cylinder($fn = 200, h = mount_length, r = mount_thickness / 2, center = true);
            cylinder($fn = 200, h = mount_thickness * 1.1, r = drill_hole / 2, center = true);
          }
        }
      }
  }
*/

  translate([0, 0, thickness / 2]){
    difference(){
      cube(size = [length, width, thickness], center = true);    
      translate([0, 0, thickness/2]){      
        cube(size = [length * 1.1, bar_width, bar_thickness], center = true);
      }

      translate([-(length)/2 + edge, width/2 - (width - bar_width)/4, 0]){
        cylinder($fn = 200, h = thickness * 1.1, r = drill_hole / 2, center = true);
      }
      translate([length/2 - edge, width/2 - (width - bar_width)/4, 0]){
        cylinder($fn = 200, h = thickness * 1.1, r = drill_hole / 2, center = true);
      }
      translate([-(length)/2 + edge, -width/2 + (width - bar_width)/4, 0]){
        cylinder($fn = 200, h = thickness * 1.1, r = drill_hole / 2, center = true);
      }
      translate([length/2 - edge, -width/2 + (width - bar_width)/4, 0]){
        cylinder($fn = 200, h = thickness * 1.1, r = drill_hole / 2, center = true);
      }
    }
  }
}

module BearingHolderClamp(){
  thickness = 5;
  length = 20;
  width = 40;
  drill_hole_circle = 25;
  edge = 5;
  nut_diameter = 15;
  nut_thickness = 7;
  clamp_thickness = thickness;
  clamp_length = length;
  translate([0, 0, thickness/2]){
    difference(){
      cube(size = [clamp_length, width, clamp_thickness], center = true);
      translate([0, 0, clamp_thickness/2 + 1]){
        cube(size = [clamp_length * 1.1, bar_width, bar_thickness], center = true);
      }
      translate([-(clamp_length)/2 + edge, width/2 - (width - bar_width)/4, 0]){
        cylinder($fn = 200, h = thickness * 1.1, r = drill_hole / 2, center = true);
      }
      translate([(clamp_length)/2 - edge, width/2 - (width - bar_width)/4, 0]){
        cylinder($fn = 200, h = thickness * 1.1, r = drill_hole / 2, center = true);
      }
      translate([(clamp_length)/2 - edge, -width/2 + (width - bar_width)/4, 0]){
        cylinder($fn = 200, h = thickness * 1.1, r = drill_hole / 2, center = true);
      }
      translate([-(clamp_length)/2 + edge, -width/2 + (width - bar_width)/4, 0]){
        cylinder($fn = 200, h = thickness * 1.1, r = drill_hole / 2, center = true);
      }
    }
  }

}

module linear_bearing(){
  draw_ball_bearing = 0;
  
  bearing_diameter = 19;
  bearing_thickness = 6;
  bearing_hole = 5.5;
  bearing_space = 1;
  tube_edge = 20;
  
  base_thickness = 2;

  spacer_diameter = bearing_hole * 1.8;
  spacer_thickness = 1;

  bolt_diameter = 5;
  //length = bearing_diameter + bearing_space * 2;
  length =10;


  socket_length = 10;
  mount_height = 10;
  clamp_hole = 3.5;
  clamp_length = sqrt(tube_edge * tube_edge * 2) + clamp_hole + 25;
  clamp_width = 10;


  a = sqrt(tube_edge * tube_edge / 8);
  b = sqrt(bearing_diameter * bearing_diameter / 2);
  c = sqrt(bearing_thickness * bearing_thickness / 8);

  width = sqrt(2 * (a + b - c) * (a + b - c));

  //hole_pos = a - sqrt(bearing_thickness * bearing_thickness / 8);

  //width = bearing_diameter * 1.2;
  hole_pos = width - bearing_diameter / 2;

  d = (bearing_diameter - spacer_diameter) / 2;
  e = sqrt(d * d / 2);
  e = 2;

  cutting_tip = (a + b + c - e);

  //clamp_thickness = b - sqrt(spacer_thickness * spacer_thickness / 2) - e / 2;
  clamp_thickness = 4;

  $fn = 50;
  //$fa = 30;

  translate([0, length / 2, base_thickness + clamp_thickness]){
    //base plate
    translate([0, 0, -base_thickness / 2]){
      cube(size = [(width - spacer_thickness * 2) * sqrt(2), length, base_thickness], center = true);
    }

      // Spacer
      rotate([0, 45, 0]){
        translate([hole_pos - width / 2,0, (width - spacer_thickness) / 2]){
          difference(){
            cylinder($fa = 12, $fs = 2, h = spacer_thickness, r = spacer_diameter / 2, center = true);
            cylinder($fa = 12, $fs = 2, h = 100, r = bearing_hole / 2, center = true);      
          }
        }
      }
      // Spacer
      rotate([0, 135, 0]){
        translate([hole_pos - width / 2, 0, -(width - spacer_thickness) / 2]){
          difference(){
            cylinder($fa = 12, $fs = 2, h = spacer_thickness, r = spacer_diameter / 2, center = true);
            cylinder($fa = 12, $fs = 2, h = 100, r = bearing_hole / 2, center = true);      
          }
        }
      }
    
    if(draw_ball_bearing == 1){
      //Ball bearing
      rotate([0, 45, 0]){
      difference(){
          translate([hole_pos - width / 2, 0, (width  + bearing_thickness) / 2]){
            cylinder($fa = 12, $fs = 2, h = bearing_thickness, r = bearing_diameter / 2, center = true);      
          }
          translate([hole_pos - width / 2, 0, 0]){
            cylinder($fa = 12, $fs = 2, h = 100, r = bearing_hole / 2, center = true);      
          }
        }
      }
    }
     
    difference(){
      //Body cube
      rotate([0, 45, 0]){
        cube(size = [width - spacer_thickness * 2, length, width - spacer_thickness * 2], center = true);
      }
      //Cutting tip
      translate([0, 0, cutting_tip]){
        rotate([0, 45, 0]){
          cube(size = [tube_edge, (length + bearing_space * 2) * 1.01, tube_edge], center = true);
        }
      }
        //bearing hole
        rotate([0, 45, 0]){
          translate([hole_pos - width / 2, 0, 0]){
            cylinder($fa = 12, $fs = 2, h = 100, r = bearing_hole / 2, center = true);      
          }
        }
        //bearing hole
        rotate([0, 135, 0]){
          translate([hole_pos - width / 2, 0, 0]){
            cylinder($fa = 12, $fs = 2, h = 100, r = bearing_hole / 2, center = true);      
          }
        }
      
      //cutting lower side of cube
      translate([0, 0, -width/2]){
          cube(size = [width * sqrt(2.001), (length + bearing_space * 2) * 1.01, width], center = true);
      }
    }

  //clamp 1
      translate([0, 0, -(clamp_thickness)/2 - base_thickness]){
        difference(){
          cube(size = [clamp_length , clamp_width, clamp_thickness], center = true);
          
          translate([clamp_length / 2, 0, 0]){
            cylinder(h = clamp_thickness * 1.01, r = clamp_hole / 2, center = true);
          }
          translate([-clamp_length / 2, 0, 0]){
            cylinder(h = clamp_thickness * 1.01, r = clamp_hole / 2, center = true);
          }
        }
        translate([clamp_length / 2, 0, 0]){
          difference(){
            cylinder(h = clamp_thickness, r = clamp_width / 2, center = true);
            cylinder(h = clamp_thickness * 1.01, r = clamp_hole / 2, center = true);
          }
        }
        translate([-clamp_length / 2, 0, 0]){
          difference(){
            cylinder(h = clamp_thickness, r = clamp_width / 2, center = true);
            cylinder(h = clamp_thickness * 1.01, r = clamp_hole / 2, center = true);
          }
        }
      }
/*
  //clamp 2
      translate([0, -(length + clamp_width)/2 - bearing_space, clamp_thickness/2]){
        difference(){
          cube(size = [clamp_length , clamp_width, clamp_thickness], center = true);

          //Cutting tip
          translate([0, 0, cutting_tip - clamp_thickness/2]){
            rotate([0, 45, 0]){
              cube(size = [tube_edge, length * 1.01, tube_edge], center = true);
            }
          }

          translate([clamp_length / 2, 0, 0]){
            cylinder(h = clamp_thickness * 1.01, r = clamp_hole / 2, center = true);
          }
          translate([-clamp_length / 2, 0, 0]){
            cylinder(h = clamp_thickness * 1.01, r = clamp_hole / 2, center = true);
          }
        }
        translate([clamp_length / 2, 0, 0]){
          difference(){
            cylinder(h = clamp_thickness, r = clamp_width / 2, center = true);
            cylinder(h = clamp_thickness * 1.01, r = clamp_hole / 2, center = true);
          }
        }
        translate([-clamp_length / 2, 0, 0]){
          difference(){
            cylinder(h = clamp_thickness, r = clamp_width / 2, center = true);
            cylinder(h = clamp_thickness * 1.01, r = clamp_hole / 2, center = true);
          }
        }
      }
*/      
    }
}

module SpoolHolder(){
  drill_hole = 5;
  wall_thickness = 3;
  base_length = 30;
  holder_diameter = 11;
  edge_length = 20;
  bar_width = 20.5;
  width = bar_width + wall_thickness * 2;
  height = 150;
  thickness = 10;

  translate([width / 2 - wall_thickness, (height - wall_thickness) / 2, 0]){
    linear_extrude(height = base_length, scale = [1, 0]){
      translate([0, -edge_length, 0]){
        polygon(points = [ [0, 0], 
                            [0, edge_length],
                            [wall_thickness, edge_length],
                            [wall_thickness, 0]

                          ], convexity = 10, slices = 20);
      }
    }
  }
  translate([-width / 2, (height - wall_thickness) / 2, 0]){
    linear_extrude(height = base_length, scale = [1, 0]){
      translate([0, -edge_length, 0]){
        polygon(points = [ [0, 0], 
                            [0, edge_length],
                            [wall_thickness, edge_length],
                            [wall_thickness, 0]

                          ], convexity = 10, slices = 20);
      }
    }
  }

  translate([0, 0, thickness / 2]){
    difference(){
      cube(size = [width, height, thickness], center = true);
        translate([0, -height/2, 0]){
          cube(size = [holder_diameter, holder_diameter, thickness * 1.1], center = true);
        }
        translate([0, -height/2+holder_diameter/2, 0]){
          cylinder($fn = 200, $fs = 2, h = thickness * 1.1, r = holder_diameter / 2, center = true);
        }
    }
  }
  translate([0, height / 2, base_length / 2]){
    translate([bar_width / 2 + wall_thickness / 2, bar_width / 4, 0]){
      cube(size = [wall_thickness, bar_width / 2, base_length], center = true);
    }
    translate([-(bar_width / 2 + wall_thickness / 2), bar_width / 4, 0]){
      cube(size = [wall_thickness, bar_width / 2, base_length], center = true);
    }
    difference(){
      cube(size = [width, wall_thickness, base_length], center = true);
      rotate([90,0,0]){
        translate([0, thickness/2, 0]){
          cylinder($fn = 200, $fs = 2, h = wall_thickness * 1.1, r = drill_hole / 2, center = true);
        }
      }
      
    }


  }


}
